==> libcamera-docs-0.0.4-3-armv7h.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/enumvalues_b.js <==
var searchData=
[
  ['noisereductionmodefast_0',['NoiseReductionModeFast',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19acc8dc1f8e9201da6063e4dcb13909e8c',1,'libcamera::controls::draft']]],
  ['noisereductionmodehighquality_1',['NoiseReductionModeHighQuality',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19a25d579ef22b374ffa4b4ac24c1067111',1,'libcamera::controls::draft']]],
  ['noisereductionmodeminimal_2',['NoiseReductionModeMinimal',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19aa65618a99630bfe5b15d5cda5f231277',1,'libcamera::controls::draft']]],
  ['noisereductionmodeoff_3',['NoiseReductionModeOff',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19ab4fff75b7c2146e863343ef4878a432a',1,'libcamera::controls::draft']]],
  ['noisereductionmodezsl_4',['NoiseReductionModeZSL',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19aba70ba432ee6b788b978d2081558574d',1,'libcamera::controls::draft']]],
  ['none_5',['None',['../classlibcamera_1_1Message.html#a7ae15d74f028344ba827ea8ba4d77fa5a2cf8f48814353e436d4f5fc4b9f8b713',1,'libcamera::Message::None()'],['../classlibcamera_1_1CameraConfiguration.html#a31c0735858af75d5506ab5d433c1cbb9a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::CameraConfiguration::None()'],['../classlibcamera_1_1ColorSpace.html#a6c38886cf640948d04502d365d9e0ec9a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::ColorSpace::None()'],['../classlibcamera_1_1BayerFormat.html#a2c2c8def2a008fae9fd23616e59086a7a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::BayerFormat::None()']]],
  ['nooption_6',['NoOption',['../classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb',1,'libcamera::File']]],
  ['normalexit_7',['NormalExit',['../classlibcamera_1_1Process.html#a826f917f3d1118206f0621254db23f21a27d4ed0afe429fc5d31cc32f59c6962e',1,'libcamera::Process']]],
  ['notexited_8',['NotExited',['../classlibcamera_1_1Process.html#a826f917f3d1118206f0621254db23f21a8be3e782c2eac2f36864480e5350904a',1,'libcamera::Process']]],
  ['notopen_9',['NotOpen',['../classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cbabdd7de68889646349ad64c3f6404b635',1,'libcamera::File']]]
];

==> libcamera-docs-0.1.0-2-armv7h.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/enumvalues_b.js <==
var searchData=
[
  ['noisereductionmodefast_0',['NoiseReductionModeFast',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19acc8dc1f8e9201da6063e4dcb13909e8c',1,'libcamera::controls::draft']]],
  ['noisereductionmodehighquality_1',['NoiseReductionModeHighQuality',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19a25d579ef22b374ffa4b4ac24c1067111',1,'libcamera::controls::draft']]],
  ['noisereductionmodeminimal_2',['NoiseReductionModeMinimal',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19aa65618a99630bfe5b15d5cda5f231277',1,'libcamera::controls::draft']]],
  ['noisereductionmodeoff_3',['NoiseReductionModeOff',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19ab4fff75b7c2146e863343ef4878a432a',1,'libcamera::controls::draft']]],
  ['noisereductionmodezsl_4',['NoiseReductionModeZSL',['../namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19aba70ba432ee6b788b978d2081558574d',1,'libcamera::controls::draft']]],
  ['none_5',['none',['../classlibcamera_1_1Message.html#a7ae15d74f028344ba827ea8ba4d77fa5a2cf8f48814353e436d4f5fc4b9f8b713',1,'libcamera::Message::None'],['../classlibcamera_1_1CameraConfiguration.html#a31c0735858af75d5506ab5d433c1cbb9a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::CameraConfiguration::None'],['../classlibcamera_1_1ColorSpace.html#a6c38886cf640948d04502d365d9e0ec9a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::ColorSpace::None'],['../classlibcamera_1_1BayerFormat.html#a2c2c8def2a008fae9fd23616e59086a7a6adf97f83acf6453d4a6a4b1070f3754',1,'libcamera::BayerFormat::None']]],
  ['nooption_6',['NoOption',['../classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb',1,'libcamera::File']]],
  ['normalexit_7',['NormalExit',['../classlibcamera_1_1Process.html#a826f917f3d1118206f0621254db23f21a27d4ed0afe429fc5d31cc32f59c6962e',1,'libcamera::Process']]],
  ['notexited_8',['NotExited',['../classlibcamera_1_1Process.html#a826f917f3d1118206f0621254db23f21a8be3e782c2eac2f36864480e5350904a',1,'libcamera::Process']]],
  ['notopen_9',['NotOpen',['../classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cbabdd7de68889646349ad64c3f6404b635',1,'libcamera::File']]]
];
